"""
{{ agent_name.capitalize() }} Agent Handler
{{ '=' * (agent_name|length + 14) }}
{{ description }}
"""

from evenage.core import Agent, actor

{% if tools %}# Import tools
{% for tool in tools %}from agents.{{ agent_name }}.tools import {{ tool }}
{% endfor %}{% endif %}

@actor(
    name="{{ agent_name }}",
    role="{{ role }}",
    goal="{{ goal }}",
    backstory="{{ backstory }}",
    allow_delegation={{ 'True' if allow_delegation else 'False' }},
    max_iterations={{ max_iterations }},
{% if tools %}    tools=[{% for tool in tools %}{{ tool }}.run{{ ', ' if not loop.last else '' }}{% endfor %}]
{% else %}    tools=[]
{% endif %})
class {{ agent_name.capitalize() }}Agent(Agent):
    """{{ description }}"""
    pass
