# EvenAge project configuration

project:
  name: {{ project_name }}
  version: "1.0.0"
  description: "{{ project_description }}"

# Backend configuration
backends:
  queue: redis       # redis | memory
  database: postgres # postgres | sqlite
  llm: openai        # openai | anthropic | gemini | noop
  cache: redis       # redis | inmemory
  vector: local      # local (file-based)

# Database settings
database:
  url: "${DATABASE_URL:-postgresql://evenage:evenage@localhost:5432/evenage}"

# Redis settings
redis:
  url: "${REDIS_URL:-redis://localhost:6379}"

# API settings
api:
  host: "0.0.0.0"
  port: 8000
  cors_origins:
    - "http://localhost:5173"
    - "*"

# Agent definitions
agents:
{% for agent in agents %}
  - name: {{ agent.name }}
    role: "{{ agent.role }}"
    goal: "{{ agent.goal }}"
    backstory: "{{ agent.backstory }}"
    allow_delegation: {{ agent.allow_delegation }}
    max_iterations: {{ agent.max_iterations }}
{% endfor %}
